==> accelerator-2020.2.14.dev1.tar.gz: accelerator-2020.2.14.dev1/accelerator/standard_methods/a_dataset_filter_columns.py <==
############################################################################
#                                                                          #
# Copyright (c) 2017 eBay Inc.                                             #
# Modifications copyright (c) 2018-2019 Carl Drougge                       #
#                                                                          #
# Licensed under the Apache License, Version 2.0 (the "License");          #
# you may not use this file except in compliance with the License.         #
# You may obtain a copy of the License at                                  #
#                                                                          #
#  http://www.apache.org/licenses/LICENSE-2.0                              #
#                                                                          #
# Unless required by applicable law or agreed to in writing, software      #
# distributed under the License is distributed on an "AS IS" BASIS,        #
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. #
# See the License for the specific language governing permissions and      #
# limitations under the License.                                           #
#                                                                          #
############################################################################

from __future__ import absolute_import

description = r"""Make only some columns from a dataset visible"""

from accelerator.extras import RequiredOption

options = dict(
	columns = RequiredOption(["colname1", "colname2", "..."]),
)

datasets = ("source",)

def synthesis():
	datasets.source.link_to_here(column_filter=options.columns)

==> accelerator-2020.6.18.dev1.tar.gz: accelerator-2020.6.18.dev1/accelerator/standard_methods/a_dataset_filter_columns.py <==
############################################################################
#                                                                          #
# Copyright (c) 2017 eBay Inc.                                             #
# Modifications copyright (c) 2018-2020 Carl Drougge                       #
#                                                                          #
# Licensed under the Apache License, Version 2.0 (the "License");          #
# you may not use this file except in compliance with the License.         #
# You may obtain a copy of the License at                                  #
#                                                                          #
#  http://www.apache.org/licenses/LICENSE-2.0                              #
#                                                                          #
# Unless required by applicable law or agreed to in writing, software      #
# distributed under the License is distributed on an "AS IS" BASIS,        #
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. #
# See the License for the specific language governing permissions and      #
# limitations under the License.                                           #
#                                                                          #
############################################################################

from __future__ import absolute_import

description = r"""Make only some columns from a dataset visible."""

from accelerator.extras import RequiredOption

options = dict(
	columns = RequiredOption(["colname1", "colname2", "..."]),
)

datasets = ("source",)

def synthesis():
	datasets.source.link_to_here(column_filter=options.columns)
